@@ -20,18 +20,17 @@ class AbstractFloorSheet(BaseSpriteLoader):
     _chunk_size = 128
     _chunk_map = {
         "push_block": (7, 0, 8, 1),
-        "bone_block": (10, 2, 11, 3),
-        "ladder": (4, 0, 5, 2),
-        "ladder_plat": (4, 2, 5, 4),
-        "entrance": (0, 7, 3, 9),
+        "entrance": (0.5, 7, 3, 9),
+        "entrance_shortcut": (0.5, 7, 3, 9),
+        "door": (0.5, 7, 3, 9),
         # Exit is not on even 128 pixel boundaries RIP even numbers
-        "exit": (0, 9.5, 3, 11.5),
+        "exit": (0.5, 9.5, 3, 11.5),
         "door2": (8, 6, 10, 8),
         # door2_secret is the same as door2, but gets dirt/push_block in front
         "door2_secret": (8, 6, 10, 8),
         "spikes": (5, 9, 6, 10),
-        "altar": (10, 0, 12, 2),
         "dirt": (0, 0, 4, 7),
+        "floor": (0, 0, 1, 1),
         "ghist_door2": (10, 6, 12, 8),
     }
     _additional_chunks = {}
